@@ -5,7 +5,7 @@ Code is based on GZipMiddleware shipped with starlette.
 
 import io
 
-from brotli import MODE_GENERIC, MODE_FONT, MODE_TEXT, Compressor  # type: ignore
+from brotli.brotli import MODE_GENERIC, MODE_FONT, MODE_TEXT, Compressor  # type: ignore
 from starlette.datastructures import Headers, MutableHeaders
 from starlette.types import ASGIApp, Message, Receive, Scope, Send
 
